ChoicePage class

Inheritance

Constructors

ChoicePage({Key? key, required String token, required String id, required String amount, String success_redirect_url = "", String error_redirect_url = "", String reference = '', bool hide_identity_form = false, String style = '', String gender = '', String name_shop = '', String redirecturl = '', String errorredirecturl = '', Map<String, dynamic> callback_info = const {}, String trans_key = '', AppLocale locale = AppLocale.fr, void onPaymentResult(PaymentResult)?})
ChoicePage.autoLocale({Key? key, required String token, required String id, required String amount, String success_redirect_url = "", String error_redirect_url = "", String reference = '', bool hide_identity_form = false, String style = '', String gender = '', String name_shop = '', String redirecturl = '', String errorredirecturl = '', Map<String, dynamic> callback_info = const {}, String trans_key = '', void onPaymentResult(PaymentResult)?})

Properties

amount String
final
callback_info Map<String, dynamic>
final
error_redirect_url String
final
errorredirecturl String
final
gender String
final
hashCode int
The hash code for this object.
no setterinherited
hide_identity_form bool
final
id String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale AppLocale
final
name_shop String
final
onPaymentResult → void Function(PaymentResult)?
final
redirecturl String
final
reference String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String
final
success_redirect_url String
final
token String
final
trans_key String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChoicePage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited